# -*- coding: utf-8 -*-
"""Onto-crawl API section."""
import re
from os.path import join
from pathlib import Path
from typing import Generator, Optional

from github import Github

# Token.txt unique to every user.
# For more information:
#   https://docs.github.com/en/enterprise-server@3.4/authentication/keeping-your-account-and-data-secure/creating-a-personal-access-token
# Save the token in a txt file as named below.
SRC = Path(__file__).parent
TOKEN_FILE = join(SRC, "token.txt")

with open(TOKEN_FILE, "r") as t:
    TOKEN = t.read().rstrip()

# Example for API: https://pygithub.readthedocs.io/en/latest/examples.html


def get_issues(
    repository_name: str,
    title_search: Optional[str] = None,
    label: Optional[str] = None,
    state: str = "open",
) -> Generator:
    """Get issues of specific states from a Github repository.

    :param repository_name: Name of the repository [org/repo]
    :param title_search: Regex for title of the issue.
    :param state: State of the issue e.g. open, close etc., defaults to "open"
    :yield: Issue names that match the regex.
    """
    g = Github(TOKEN)
    repo = g.get_repo(repository_name)
    label_object = None
    if label:
        label_object = repo.get_label(label)

    issues = repo.get_issues(state=state)
    for issue in issues:
        if title_search and re.match(title_search, issue.title):
            yield issue
        if label_object and label_object in issue.labels:
            yield issue



# -*- coding: utf-8 -*-

"""Command line interface for :mod:`onto_crawler`."""

import logging
from typing import TextIO

import click

from onto_crawler import __version__
from onto_crawler.api import get_issues

__all__ = [
    "main",
]

logger = logging.getLogger(__name__)


@click.group()
@click.option("-v", "--verbose", count=True)
@click.option("-q", "--quiet")
@click.version_option(__version__)
def main(verbose: int, quiet: bool):
    """CLI for onto_crawler.

    :param verbose: Verbosity while running.
    :param quiet: Boolean to be quiet or verbose.
    """
    if verbose >= 2:
        logger.setLevel(level=logging.DEBUG)
    elif verbose == 1:
        logger.setLevel(level=logging.INFO)
    else:
        logger.setLevel(level=logging.WARNING)
    if quiet:
        logger.setLevel(level=logging.ERROR)


@main.command()
@click.option(
    "-r",
    "--repo",
    default="monarch-initiative/mondo",
    help="Org/name of the github repo.",
)
@click.option(
    "-s",
    "--state",
    default="open",
    help="State of the issue. [open, close etc.]",
)
@click.option(
    "-o",
    "--output",
    help="Output could be a file or sys.stdout.",
)
@click.option(
    "-t",
    "--title-search",
    help="Filter based on a search for pattern within title of issue.",
)
@click.option(
    "-l",
    "--label",
    help="Filter based on a search for label of issue.",
)
def issues(
    repo: str, state: str, title_search: str, label: str, output: TextIO
):
    """Get issues of specific states, title or labels from a Github repository.

    :param repo: GitHub repository name [org/repo_name]
    :param state: State of issue ["open", "close" etc.]
    :param title_search: String lookup in title of issue.
    :param label: Label lookup for issues.
    :param output: Output location.
    """
    for issue in get_issues(
        repository_name=repo,
        state=state,
        title_search=title_search,
        label=label,
    ):
        print(issue, file=output)


if __name__ == "__main__":
    main()
